@@ -1,7 +1,7 @@
 package Module::FatPack;
 
-our $DATE = '2015-10-03'; # DATE
-our $VERSION = '0.09'; # VERSION
+our $DATE = '2016-02-09'; # DATE
+our $VERSION = '0.10'; # VERSION
 
 use 5.010001;
 use strict;
@@ -84,6 +84,15 @@ _
         },
 
     },
+    examples => [
+        {
+            summary => 'Fatpack two modules',
+            src => 'fatpack-modules Text::Table::Tiny Try::Tiny',
+            src_plang => 'bash',
+            test => 0,
+            'x.doc.show_result' => 0,
+        },
+    ],
 };
 sub fatpack_modules {
     my %args = @_;
@@ -209,13 +218,7 @@ Module::FatPack - Generate source code that contains fatpacked modules
 
 =head1 VERSION
 
-This document describes version 0.09 of Module::FatPack (from Perl distribution Module-FatPack), released on 2015-10-03.
-
-=head1 SEE ALSO
-
-L<App::FatPack>, L<App::depak>
-
-L<fatpack-modules>, CLI for C<fatpack_modules>
+This document describes version 0.10 of Module::FatPack (from Perl distribution Module-FatPack), released on 2016-02-09.
 
 =head1 FUNCTIONS
 
@@ -230,6 +233,8 @@ via require hook) without all the other stuffs. All you need is supply the names
 of modules (or the modules' source code themselves) and you'll get the output in
 a file or string.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -315,13 +320,21 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<App::FatPack>, the original implementation.
+
+L<App::depak> for more options e.g. use various tracing methods, etc.
+
+L<fatpack-modules>, CLI for C<fatpack_modules>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2016 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
